"""
=============
radtraq.tests
=============

.. currentmodule:: radtraq.tests

This module contains sample files used for testing RadTraQ

.. autosummary::
    :toctree: generated/

    EXAMPLE_KAZR
    EXAMPLE_RASTER
"""

from .sample_files import (EXAMPLE_KAZR, EXAMPLE_RASTER, EXAMPLE_PPI)
